@@ -1,5 +1,11 @@
-from mongoengine import StringField, DictField, ReferenceField,\
-    DateTimeField, Document
+from mongoengine import (
+    StringField,
+    DictField,
+    ReferenceField,
+    DateTimeField,
+    BooleanField,
+    Document
+)
 
 
 class Role(Document):
@@ -10,6 +16,13 @@ class Role(Document):
 class User(Document):
     username = StringField(required=True, unique=True)
     password = StringField(required=True)
+
+    change_password = BooleanField(default=False)
+    """bool: Indica si es necesario realizar cambio de contraseña
+    ::
+        (default=True)
+    """
+
     role = ReferenceField(
         Role,
         dbref=True,
@@ -18,5 +31,11 @@ class User(Document):
 
 
 class WhitelistToken(Document):
-    token = StringField(required=True, unique=True)
+    uuid_access = StringField(required=True, unique=True)
+    uuid_refresh = StringField(required=True, unique=True)
+    user = ReferenceField(
+        User,
+        dbref=True,
+        required=True
+    )
     created_at = DateTimeField()
